@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Optional
 
 from fastapi import FastAPI, File
 from fastapi.testclient import TestClient
@@ -7,7 +7,7 @@ app = FastAPI()
 
 
 @app.post("/files")
-async def upload_files(files: Optional[List[bytes]] = File(None)):
+async def upload_files(files: Optional[list[bytes]] = File(None)):
     if files is None:
         return {"files_count": 0}
     return {"files_count": len(files), "sizes": [len(f) for f in files]}
