@@ -1,7 +1,8 @@
 import sys
+import warnings
 from typing import Any, Union
 
-from tests.utils import pydantic_snapshot, skip_module_if_py_gte_314
+from tests.utils import skip_module_if_py_gte_314
 
 if sys.version_info >= (3, 14):
     skip_module_if_py_gte_314()
@@ -39,179 +40,181 @@ class NewItem(NewBaseModel):
 
 app = FastAPI()
 
+with warnings.catch_warnings(record=True):
+    warnings.simplefilter("always")
 
-@app.post("/v1-to-v2/item")
-def handle_v1_item_to_v2(data: Item) -> NewItem:
-    return NewItem(
-        new_title=data.title,
-        new_size=data.size,
-        new_description=data.description,
-        new_sub=NewSubItem(new_sub_name=data.sub.name),
-        new_multi=[NewSubItem(new_sub_name=s.name) for s in data.multi],
-    )
+    @app.post("/v1-to-v2/item")
+    def handle_v1_item_to_v2(data: Item) -> NewItem:
+        return NewItem(
+            new_title=data.title,
+            new_size=data.size,
+            new_description=data.description,
+            new_sub=NewSubItem(new_sub_name=data.sub.name),
+            new_multi=[NewSubItem(new_sub_name=s.name) for s in data.multi],
+        )
 
+    @app.post("/v1-to-v2/item-filter", response_model=NewItem)
+    def handle_v1_item_to_v2_filter(data: Item) -> Any:
+        result = {
+            "new_title": data.title,
+            "new_size": data.size,
+            "new_description": data.description,
+            "new_sub": {
+                "new_sub_name": data.sub.name,
+                "new_sub_secret": "sub_hidden",
+            },
+            "new_multi": [
+                {"new_sub_name": s.name, "new_sub_secret": "sub_hidden"}
+                for s in data.multi
+            ],
+            "secret": "hidden_v1_to_v2",
+        }
+        return result
 
-@app.post("/v1-to-v2/item-filter", response_model=NewItem)
-def handle_v1_item_to_v2_filter(data: Item) -> Any:
-    result = {
-        "new_title": data.title,
-        "new_size": data.size,
-        "new_description": data.description,
-        "new_sub": {"new_sub_name": data.sub.name, "new_sub_secret": "sub_hidden"},
-        "new_multi": [
-            {"new_sub_name": s.name, "new_sub_secret": "sub_hidden"} for s in data.multi
-        ],
-        "secret": "hidden_v1_to_v2",
-    }
-    return result
+    @app.post("/v2-to-v1/item")
+    def handle_v2_item_to_v1(data: NewItem) -> Item:
+        return Item(
+            title=data.new_title,
+            size=data.new_size,
+            description=data.new_description,
+            sub=SubItem(name=data.new_sub.new_sub_name),
+            multi=[SubItem(name=s.new_sub_name) for s in data.new_multi],
+        )
 
+    @app.post("/v2-to-v1/item-filter", response_model=Item)
+    def handle_v2_item_to_v1_filter(data: NewItem) -> Any:
+        result = {
+            "title": data.new_title,
+            "size": data.new_size,
+            "description": data.new_description,
+            "sub": {"name": data.new_sub.new_sub_name, "sub_secret": "sub_hidden"},
+            "multi": [
+                {"name": s.new_sub_name, "sub_secret": "sub_hidden"}
+                for s in data.new_multi
+            ],
+            "secret": "hidden_v2_to_v1",
+        }
+        return result
 
-@app.post("/v2-to-v1/item")
-def handle_v2_item_to_v1(data: NewItem) -> Item:
-    return Item(
-        title=data.new_title,
-        size=data.new_size,
-        description=data.new_description,
-        sub=SubItem(name=data.new_sub.new_sub_name),
-        multi=[SubItem(name=s.new_sub_name) for s in data.new_multi],
-    )
+    @app.post("/v1-to-v2/item-to-list")
+    def handle_v1_item_to_v2_list(data: Item) -> list[NewItem]:
+        converted = NewItem(
+            new_title=data.title,
+            new_size=data.size,
+            new_description=data.description,
+            new_sub=NewSubItem(new_sub_name=data.sub.name),
+            new_multi=[NewSubItem(new_sub_name=s.name) for s in data.multi],
+        )
+        return [converted, converted]
 
+    @app.post("/v1-to-v2/list-to-list")
+    def handle_v1_list_to_v2_list(data: list[Item]) -> list[NewItem]:
+        result = []
+        for item in data:
+            result.append(
+                NewItem(
+                    new_title=item.title,
+                    new_size=item.size,
+                    new_description=item.description,
+                    new_sub=NewSubItem(new_sub_name=item.sub.name),
+                    new_multi=[NewSubItem(new_sub_name=s.name) for s in item.multi],
+                )
+            )
+        return result
 
-@app.post("/v2-to-v1/item-filter", response_model=Item)
-def handle_v2_item_to_v1_filter(data: NewItem) -> Any:
-    result = {
-        "title": data.new_title,
-        "size": data.new_size,
-        "description": data.new_description,
-        "sub": {"name": data.new_sub.new_sub_name, "sub_secret": "sub_hidden"},
-        "multi": [
-            {"name": s.new_sub_name, "sub_secret": "sub_hidden"} for s in data.new_multi
-        ],
-        "secret": "hidden_v2_to_v1",
-    }
-    return result
+    @app.post("/v1-to-v2/list-to-list-filter", response_model=list[NewItem])
+    def handle_v1_list_to_v2_list_filter(data: list[Item]) -> Any:
+        result = []
+        for item in data:
+            converted = {
+                "new_title": item.title,
+                "new_size": item.size,
+                "new_description": item.description,
+                "new_sub": {
+                    "new_sub_name": item.sub.name,
+                    "new_sub_secret": "sub_hidden",
+                },
+                "new_multi": [
+                    {"new_sub_name": s.name, "new_sub_secret": "sub_hidden"}
+                    for s in item.multi
+                ],
+                "secret": "hidden_v2_to_v1",
+            }
+            result.append(converted)
+        return result
 
-
-@app.post("/v1-to-v2/item-to-list")
-def handle_v1_item_to_v2_list(data: Item) -> list[NewItem]:
-    converted = NewItem(
-        new_title=data.title,
-        new_size=data.size,
-        new_description=data.description,
-        new_sub=NewSubItem(new_sub_name=data.sub.name),
-        new_multi=[NewSubItem(new_sub_name=s.name) for s in data.multi],
-    )
-    return [converted, converted]
-
-
-@app.post("/v1-to-v2/list-to-list")
-def handle_v1_list_to_v2_list(data: list[Item]) -> list[NewItem]:
-    result = []
-    for item in data:
-        result.append(
-            NewItem(
+    @app.post("/v1-to-v2/list-to-item")
+    def handle_v1_list_to_v2_item(data: list[Item]) -> NewItem:
+        if data:
+            item = data[0]
+            return NewItem(
                 new_title=item.title,
                 new_size=item.size,
                 new_description=item.description,
                 new_sub=NewSubItem(new_sub_name=item.sub.name),
                 new_multi=[NewSubItem(new_sub_name=s.name) for s in item.multi],
             )
+        return NewItem(new_title="", new_size=0, new_sub=NewSubItem(new_sub_name=""))
+
+    @app.post("/v2-to-v1/item-to-list")
+    def handle_v2_item_to_v1_list(data: NewItem) -> list[Item]:
+        converted = Item(
+            title=data.new_title,
+            size=data.new_size,
+            description=data.new_description,
+            sub=SubItem(name=data.new_sub.new_sub_name),
+            multi=[SubItem(name=s.new_sub_name) for s in data.new_multi],
         )
-    return result
+        return [converted, converted]
 
+    @app.post("/v2-to-v1/list-to-list")
+    def handle_v2_list_to_v1_list(data: list[NewItem]) -> list[Item]:
+        result = []
+        for item in data:
+            result.append(
+                Item(
+                    title=item.new_title,
+                    size=item.new_size,
+                    description=item.new_description,
+                    sub=SubItem(name=item.new_sub.new_sub_name),
+                    multi=[SubItem(name=s.new_sub_name) for s in item.new_multi],
+                )
+            )
+        return result
 
-@app.post("/v1-to-v2/list-to-list-filter", response_model=list[NewItem])
-def handle_v1_list_to_v2_list_filter(data: list[Item]) -> Any:
-    result = []
-    for item in data:
-        converted = {
-            "new_title": item.title,
-            "new_size": item.size,
-            "new_description": item.description,
-            "new_sub": {"new_sub_name": item.sub.name, "new_sub_secret": "sub_hidden"},
-            "new_multi": [
-                {"new_sub_name": s.name, "new_sub_secret": "sub_hidden"}
-                for s in item.multi
-            ],
-            "secret": "hidden_v2_to_v1",
-        }
-        result.append(converted)
-    return result
+    @app.post("/v2-to-v1/list-to-list-filter", response_model=list[Item])
+    def handle_v2_list_to_v1_list_filter(data: list[NewItem]) -> Any:
+        result = []
+        for item in data:
+            converted = {
+                "title": item.new_title,
+                "size": item.new_size,
+                "description": item.new_description,
+                "sub": {
+                    "name": item.new_sub.new_sub_name,
+                    "sub_secret": "sub_hidden",
+                },
+                "multi": [
+                    {"name": s.new_sub_name, "sub_secret": "sub_hidden"}
+                    for s in item.new_multi
+                ],
+                "secret": "hidden_v2_to_v1",
+            }
+            result.append(converted)
+        return result
 
-
-@app.post("/v1-to-v2/list-to-item")
-def handle_v1_list_to_v2_item(data: list[Item]) -> NewItem:
-    if data:
-        item = data[0]
-        return NewItem(
-            new_title=item.title,
-            new_size=item.size,
-            new_description=item.description,
-            new_sub=NewSubItem(new_sub_name=item.sub.name),
-            new_multi=[NewSubItem(new_sub_name=s.name) for s in item.multi],
-        )
-    return NewItem(new_title="", new_size=0, new_sub=NewSubItem(new_sub_name=""))
-
-
-@app.post("/v2-to-v1/item-to-list")
-def handle_v2_item_to_v1_list(data: NewItem) -> list[Item]:
-    converted = Item(
-        title=data.new_title,
-        size=data.new_size,
-        description=data.new_description,
-        sub=SubItem(name=data.new_sub.new_sub_name),
-        multi=[SubItem(name=s.new_sub_name) for s in data.new_multi],
-    )
-    return [converted, converted]
-
-
-@app.post("/v2-to-v1/list-to-list")
-def handle_v2_list_to_v1_list(data: list[NewItem]) -> list[Item]:
-    result = []
-    for item in data:
-        result.append(
-            Item(
+    @app.post("/v2-to-v1/list-to-item")
+    def handle_v2_list_to_v1_item(data: list[NewItem]) -> Item:
+        if data:
+            item = data[0]
+            return Item(
                 title=item.new_title,
                 size=item.new_size,
                 description=item.new_description,
                 sub=SubItem(name=item.new_sub.new_sub_name),
                 multi=[SubItem(name=s.new_sub_name) for s in item.new_multi],
             )
-        )
-    return result
-
-
-@app.post("/v2-to-v1/list-to-list-filter", response_model=list[Item])
-def handle_v2_list_to_v1_list_filter(data: list[NewItem]) -> Any:
-    result = []
-    for item in data:
-        converted = {
-            "title": item.new_title,
-            "size": item.new_size,
-            "description": item.new_description,
-            "sub": {"name": item.new_sub.new_sub_name, "sub_secret": "sub_hidden"},
-            "multi": [
-                {"name": s.new_sub_name, "sub_secret": "sub_hidden"}
-                for s in item.new_multi
-            ],
-            "secret": "hidden_v2_to_v1",
-        }
-        result.append(converted)
-    return result
-
-
-@app.post("/v2-to-v1/list-to-item")
-def handle_v2_list_to_v1_item(data: list[NewItem]) -> Item:
-    if data:
-        item = data[0]
-        return Item(
-            title=item.new_title,
-            size=item.new_size,
-            description=item.new_description,
-            sub=SubItem(name=item.new_sub.new_sub_name),
-            multi=[SubItem(name=s.new_sub_name) for s in item.new_multi],
-        )
-    return Item(title="", size=0, sub=SubItem(name=""))
+        return Item(title="", size=0, sub=SubItem(name=""))
 
 
 client = TestClient(app)
@@ -668,38 +671,20 @@ def test_v2_to_v1_validation_error():
     assert response.status_code == 422, response.text
     assert response.json() == snapshot(
         {
-            "detail": pydantic_snapshot(
-                v2=snapshot(
-                    [
-                        {
-                            "type": "missing",
-                            "loc": ["body", "new_size"],
-                            "msg": "Field required",
-                            "input": {"new_title": "Missing fields"},
-                        },
-                        {
-                            "type": "missing",
-                            "loc": ["body", "new_sub"],
-                            "msg": "Field required",
-                            "input": {"new_title": "Missing fields"},
-                        },
-                    ]
-                ),
-                v1=snapshot(
-                    [
-                        {
-                            "loc": ["body", "new_size"],
-                            "msg": "field required",
-                            "type": "value_error.missing",
-                        },
-                        {
-                            "loc": ["body", "new_sub"],
-                            "msg": "field required",
-                            "type": "value_error.missing",
-                        },
-                    ]
-                ),
-            )
+            "detail": [
+                {
+                    "type": "missing",
+                    "loc": ["body", "new_size"],
+                    "msg": "Field required",
+                    "input": {"new_title": "Missing fields"},
+                },
+                {
+                    "type": "missing",
+                    "loc": ["body", "new_sub"],
+                    "msg": "Field required",
+                    "input": {"new_title": "Missing fields"},
+                },
+            ]
         }
     )
 
@@ -717,23 +702,12 @@ def test_v2_to_v1_nested_validation_error():
     assert response.json() == snapshot(
         {
             "detail": [
-                pydantic_snapshot(
-                    v2=snapshot(
-                        {
-                            "type": "missing",
-                            "loc": ["body", "new_sub", "new_sub_name"],
-                            "msg": "Field required",
-                            "input": {"wrong_field": "value"},
-                        }
-                    ),
-                    v1=snapshot(
-                        {
-                            "loc": ["body", "new_sub", "new_sub_name"],
-                            "msg": "field required",
-                            "type": "value_error.missing",
-                        }
-                    ),
-                )
+                {
+                    "type": "missing",
+                    "loc": ["body", "new_sub", "new_sub_name"],
+                    "msg": "Field required",
+                    "input": {"wrong_field": "value"},
+                }
             ]
         }
     )
@@ -777,38 +751,20 @@ def test_v2_list_validation_error():
     assert response.status_code == 422, response.text
     assert response.json() == snapshot(
         {
-            "detail": pydantic_snapshot(
-                v2=snapshot(
-                    [
-                        {
-                            "type": "missing",
-                            "loc": ["body", 1, "new_size"],
-                            "msg": "Field required",
-                            "input": {"new_title": "Invalid"},
-                        },
-                        {
-                            "type": "missing",
-                            "loc": ["body", 1, "new_sub"],
-                            "msg": "Field required",
-                            "input": {"new_title": "Invalid"},
-                        },
-                    ]
-                ),
-                v1=snapshot(
-                    [
-                        {
-                            "loc": ["body", 1, "new_size"],
-                            "msg": "field required",
-                            "type": "value_error.missing",
-                        },
-                        {
-                            "loc": ["body", 1, "new_sub"],
-                            "msg": "field required",
-                            "type": "value_error.missing",
-                        },
-                    ]
-                ),
-            )
+            "detail": [
+                {
+                    "type": "missing",
+                    "loc": ["body", 1, "new_size"],
+                    "msg": "Field required",
+                    "input": {"new_title": "Invalid"},
+                },
+                {
+                    "type": "missing",
+                    "loc": ["body", 1, "new_sub"],
+                    "msg": "Field required",
+                    "input": {"new_title": "Invalid"},
+                },
+            ]
         }
     )
 
@@ -844,31 +800,18 @@ def test_invalid_list_structure_v2():
     assert response.status_code == 422, response.text
     assert response.json() == snapshot(
         {
-            "detail": pydantic_snapshot(
-                v2=snapshot(
-                    [
-                        {
-                            "type": "list_type",
-                            "loc": ["body"],
-                            "msg": "Input should be a valid list",
-                            "input": {
-                                "new_title": "Not a list",
-                                "new_size": 100,
-                                "new_sub": {"new_sub_name": "Sub"},
-                            },
-                        }
-                    ]
-                ),
-                v1=snapshot(
-                    [
-                        {
-                            "loc": ["body"],
-                            "msg": "value is not a valid list",
-                            "type": "type_error.list",
-                        }
-                    ]
-                ),
-            )
+            "detail": [
+                {
+                    "type": "list_type",
+                    "loc": ["body"],
+                    "msg": "Input should be a valid list",
+                    "input": {
+                        "new_title": "Not a list",
+                        "new_size": 100,
+                        "new_sub": {"new_sub_name": "Sub"},
+                    },
+                }
+            ]
         }
     )
 
@@ -888,21 +831,12 @@ def test_openapi_schema():
                         "requestBody": {
                             "content": {
                                 "application/json": {
-                                    "schema": pydantic_snapshot(
-                                        v2=snapshot(
-                                            {
-                                                "allOf": [
-                                                    {
-                                                        "$ref": "#/components/schemas/Item"
-                                                    }
-                                                ],
-                                                "title": "Data",
-                                            }
-                                        ),
-                                        v1=snapshot(
+                                    "schema": {
+                                        "allOf": [
                                             {"$ref": "#/components/schemas/Item"}
-                                        ),
-                                    )
+                                        ],
+                                        "title": "Data",
+                                    }
                                 }
                             },
                             "required": True,
@@ -938,21 +872,12 @@ def test_openapi_schema():
                         "requestBody": {
                             "content": {
                                 "application/json": {
-                                    "schema": pydantic_snapshot(
-                                        v2=snapshot(
-                                            {
-                                                "allOf": [
-                                                    {
-                                                        "$ref": "#/components/schemas/Item"
-                                                    }
-                                                ],
-                                                "title": "Data",
-                                            }
-                                        ),
-                                        v1=snapshot(
+                                    "schema": {
+                                        "allOf": [
                                             {"$ref": "#/components/schemas/Item"}
-                                        ),
-                                    )
+                                        ],
+                                        "title": "Data",
+                                    }
                                 }
                             },
                             "required": True,
@@ -1056,21 +981,12 @@ def test_openapi_schema():
                         "requestBody": {
                             "content": {
                                 "application/json": {
-                                    "schema": pydantic_snapshot(
-                                        v2=snapshot(
-                                            {
-                                                "allOf": [
-                                                    {
-                                                        "$ref": "#/components/schemas/Item"
-                                                    }
-                                                ],
-                                                "title": "Data",
-                                            }
-                                        ),
-                                        v1=snapshot(
+                                    "schema": {
+                                        "allOf": [
                                             {"$ref": "#/components/schemas/Item"}
-                                        ),
-                                    )
+                                        ],
+                                        "title": "Data",
+                                    }
                                 }
                             },
                             "required": True,
@@ -1440,17 +1356,10 @@ def test_openapi_schema():
                         "properties": {
                             "new_title": {"type": "string", "title": "New Title"},
                             "new_size": {"type": "integer", "title": "New Size"},
-                            "new_description": pydantic_snapshot(
-                                v2=snapshot(
-                                    {
-                                        "anyOf": [{"type": "string"}, {"type": "null"}],
-                                        "title": "New Description",
-                                    }
-                                ),
-                                v1=snapshot(
-                                    {"type": "string", "title": "New Description"}
-                                ),
-                            ),
+                            "new_description": {
+                                "anyOf": [{"type": "string"}, {"type": "null"}],
+                                "title": "New Description",
+                            },
                             "new_sub": {"$ref": "#/components/schemas/NewSubItem"},
                             "new_multi": {
                                 "items": {"$ref": "#/components/schemas/NewSubItem"},
