@@ -4,15 +4,12 @@ import pytest
 from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from ...utils import needs_py39
-
 
 @pytest.fixture(
     name="client",
     params=[
-        "tutorial001",
-        "tutorial001_an",
-        pytest.param("tutorial001_an_py39", marks=needs_py39),
+        "tutorial001_py39",
+        "tutorial001_an_py39",
     ],
 )
 def get_client(request: pytest.FixtureRequest):
