@@ -1,20 +1,14 @@
 import importlib
-from pathlib import Path
 
 import pytest
-from dirty_equals import IsDict
 from fastapi.testclient import TestClient
 
-from ...utils import needs_py310
-
 
 @pytest.fixture(
     name="client",
     params=[
-        pytest.param("tutorial001_02_py39"),
-        pytest.param("tutorial001_02_py310", marks=needs_py310),
-        pytest.param("tutorial001_02_an_py39"),
-        pytest.param("tutorial001_02_an_py310", marks=needs_py310),
+        "tutorial001_03_py39",
+        "tutorial001_03_an_py39",
     ],
 )
 def get_client(request: pytest.FixtureRequest):
@@ -24,19 +18,7 @@ def get_client(request: pytest.FixtureRequest):
     return client
 
 
-def test_post_form_no_body(client: TestClient):
-    response = client.post("/files/")
-    assert response.status_code == 200, response.text
-    assert response.json() == {"message": "No file sent"}
-
-
-def test_post_uploadfile_no_body(client: TestClient):
-    response = client.post("/uploadfile/")
-    assert response.status_code == 200, response.text
-    assert response.json() == {"message": "No upload file sent"}
-
-
-def test_post_file(tmp_path: Path, client: TestClient):
+def test_post_file(tmp_path, client: TestClient):
     path = tmp_path / "test.txt"
     path.write_bytes(b"<file content>")
 
@@ -46,7 +28,7 @@ def test_post_file(tmp_path: Path, client: TestClient):
     assert response.json() == {"file_size": 14}
 
 
-def test_post_upload_file(tmp_path: Path, client: TestClient):
+def test_post_upload_file(tmp_path, client: TestClient):
     path = tmp_path / "test.txt"
     path.write_bytes(b"<file content>")
 
@@ -70,24 +52,12 @@ def test_openapi_schema(client: TestClient):
                     "requestBody": {
                         "content": {
                             "multipart/form-data": {
-                                "schema": IsDict(
-                                    {
-                                        "allOf": [
-                                            {
-                                                "$ref": "#/components/schemas/Body_create_file_files__post"
-                                            }
-                                        ],
-                                        "title": "Body",
-                                    }
-                                )
-                                | IsDict(
-                                    # TODO: remove when deprecating Pydantic v1
-                                    {
-                                        "$ref": "#/components/schemas/Body_create_file_files__post"
-                                    }
-                                )
+                                "schema": {
+                                    "$ref": "#/components/schemas/Body_create_file_files__post"
+                                }
                             }
-                        }
+                        },
+                        "required": True,
                     },
                     "responses": {
                         "200": {
@@ -114,24 +84,12 @@ def test_openapi_schema(client: TestClient):
                     "requestBody": {
                         "content": {
                             "multipart/form-data": {
-                                "schema": IsDict(
-                                    {
-                                        "allOf": [
-                                            {
-                                                "$ref": "#/components/schemas/Body_create_upload_file_uploadfile__post"
-                                            }
-                                        ],
-                                        "title": "Body",
-                                    }
-                                )
-                                | IsDict(
-                                    # TODO: remove when deprecating Pydantic v1
-                                    {
-                                        "$ref": "#/components/schemas/Body_create_upload_file_uploadfile__post"
-                                    }
-                                )
+                                "schema": {
+                                    "$ref": "#/components/schemas/Body_create_upload_file_uploadfile__post"
+                                }
                             }
-                        }
+                        },
+                        "required": True,
                     },
                     "responses": {
                         "200": {
@@ -156,40 +114,28 @@ def test_openapi_schema(client: TestClient):
             "schemas": {
                 "Body_create_file_files__post": {
                     "title": "Body_create_file_files__post",
+                    "required": ["file"],
                     "type": "object",
                     "properties": {
-                        "file": IsDict(
-                            {
-                                "title": "File",
-                                "anyOf": [
-                                    {"type": "string", "format": "binary"},
-                                    {"type": "null"},
-                                ],
-                            }
-                        )
-                        | IsDict(
-                            # TODO: remove when deprecating Pydantic v1
-                            {"title": "File", "type": "string", "format": "binary"}
-                        )
+                        "file": {
+                            "title": "File",
+                            "type": "string",
+                            "description": "A file read as bytes",
+                            "format": "binary",
+                        }
                     },
                 },
                 "Body_create_upload_file_uploadfile__post": {
                     "title": "Body_create_upload_file_uploadfile__post",
+                    "required": ["file"],
                     "type": "object",
                     "properties": {
-                        "file": IsDict(
-                            {
-                                "title": "File",
-                                "anyOf": [
-                                    {"type": "string", "format": "binary"},
-                                    {"type": "null"},
-                                ],
-                            }
-                        )
-                        | IsDict(
-                            # TODO: remove when deprecating Pydantic v1
-                            {"title": "File", "type": "string", "format": "binary"}
-                        )
+                        "file": {
+                            "title": "File",
+                            "type": "string",
+                            "description": "A file read as UploadFile",
+                            "format": "binary",
+                        }
                     },
                 },
                 "HTTPValidationError": {
