@@ -3,7 +3,7 @@ import importlib
 import pytest
 from fastapi.testclient import TestClient
 
-from ...utils import needs_py310, needs_pydanticv2
+from ...utils import needs_py310
 
 
 @pytest.fixture(
@@ -38,7 +38,6 @@ def test_read_items(client: TestClient) -> None:
     ]
 
 
-@needs_pydanticv2
 def test_openapi_schema(client: TestClient) -> None:
     response = client.get("/openapi.json")
     assert response.status_code == 200, response.text
