@@ -1,5 +1,4 @@
 from fastapi import FastAPI
-from fastapi._compat import PYDANTIC_V2
 from pydantic import BaseModel
 
 app = FastAPI()
@@ -20,13 +19,9 @@ class RecursiveItemViaSubmodel(BaseModel):
     name: str
 
 
-if PYDANTIC_V2:
-    RecursiveItem.model_rebuild()
-    RecursiveSubitemInSubmodel.model_rebuild()
-    RecursiveItemViaSubmodel.model_rebuild()
-else:
-    RecursiveItem.update_forward_refs()
-    RecursiveSubitemInSubmodel.update_forward_refs()
+RecursiveItem.model_rebuild()
+RecursiveSubitemInSubmodel.model_rebuild()
+RecursiveItemViaSubmodel.model_rebuild()
 
 
 @app.get("/items/recursive", response_model=RecursiveItem)
